# FASTGenomics Base Library

This package serves as basis for tools managing your data on [FASTGenomics](https://beta.fastgenomics.org).

For further information, have a look at the [FASTGenomics CLI](https://pypi.org/project/fastgenomics-cli/#description).
